summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorDan Allen <dan.j.allen@gmail.com>2019-04-29 23:59:22 -0600
committerGitHub <noreply@github.com>2019-04-29 23:59:22 -0600
commitbb47c333df0aaab6daefa1f4acd3ba3d2623c0c8 (patch)
tree7399d00732e655f5f89581e3f2763d026f33fefb /lib
parent2175b806d44ef9ef942c9cc7f63e3c402652a426 (diff)
resolves #3282 rename AbstractNode#options to AbstractNode#enabled_options (PR #3285)
Diffstat (limited to 'lib')
-rw-r--r--lib/asciidoctor/abstract_node.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/asciidoctor/abstract_node.rb b/lib/asciidoctor/abstract_node.rb
index 024bbc1e..34ff17f7 100644
--- a/lib/asciidoctor/abstract_node.rb
+++ b/lib/asciidoctor/abstract_node.rb
@@ -161,10 +161,10 @@ class AbstractNode
nil
end
# Public: Retrieve the Set of option names that are set on this node
#
# Returns a [Set] of option names
- def options
+ def enabled_options
::Set.new.tap {|accum| @attributes.each_key {|k| accum << (k.slice 0, k.length - 7) if k.to_s.end_with? '-option' } }
end
@@ -161,10 +161,10 @@ class AbstractNode
nil
end
- # Public: Retrieve the Set of option names that are set on this node
+ # Public: Retrieve the Set of option names that are enabled on this node
#
# Returns a [Set] of option names